import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { MigrationBatchCreatedModel } from '../model/migrationBatchCreatedModel';
import { MigrationBatchModel } from '../model/migrationBatchModel';
import { TriggerBatchModel } from '../model/triggerBatchModel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace dataImportBatchByIdGet {
    interface Params {
        /**
        *
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace dataImportReservationsUploadPost {
    interface Params {
        /**
        * The file to upload.
        */
        formFile: Blob;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare namespace dataImportTriggerBatchPost {
    interface Params {
        /**
        *
        */
        body: TriggerBatchModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare class ImportService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Gets a batch by id
     * &lt;br&gt;You must have this scope: &#39;reservations.import&#39;.
     * @param $params.id
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    dataImportBatchByIdGet($params: dataImportBatchByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<MigrationBatchModel>;
    dataImportBatchByIdGet($params: dataImportBatchByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MigrationBatchModel>>;
    dataImportBatchByIdGet($params: dataImportBatchByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MigrationBatchModel>>;
    /**
     * Reads reservations to migrate from CSV and returns the batch id
     * The reservations will be created by-passing availability checks and offer calculation as they have been accepted  already by the hotel. Still only reservations with arrival in the future are accepted.  The values in the CSV must be delimited by &#39;;&#39;.&lt;br&gt;You must have this scope: &#39;reservations.import&#39;.
     * @param $params.formFile The file to upload.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    dataImportReservationsUploadPost($params: dataImportReservationsUploadPost.Params, observe?: 'body', reportProgress?: boolean): Observable<MigrationBatchCreatedModel>;
    dataImportReservationsUploadPost($params: dataImportReservationsUploadPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MigrationBatchCreatedModel>>;
    dataImportReservationsUploadPost($params: dataImportReservationsUploadPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MigrationBatchCreatedModel>>;
    /**
     * Triggers the asynchronous execution of a batch
     * &lt;br&gt;You must have this scope: &#39;reservations.import&#39;.
     * @param $params.body
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    dataImportTriggerBatchPost($params: dataImportTriggerBatchPost.Params, observe?: 'body', reportProgress?: boolean): Observable<MigrationBatchCreatedModel>;
    dataImportTriggerBatchPost($params: dataImportTriggerBatchPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MigrationBatchCreatedModel>>;
    dataImportTriggerBatchPost($params: dataImportTriggerBatchPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MigrationBatchCreatedModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ImportService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ImportService>;
}
