import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Optional, Inject, NgModule, SkipSelf } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpParams, HttpHeaders, HttpUrlEncodingCodec } from '@angular/common/http';

const BASE_PATH = new InjectionToken('basePath');
const COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};

class Configuration {
    constructor(configurationParameters = {}) {
        this.apiKeys = configurationParameters.apiKeys;
        this.username = configurationParameters.username;
        this.password = configurationParameters.password;
        this.accessToken = configurationParameters.accessToken;
        this.basePath = configurationParameters.basePath;
        this.withCredentials = configurationParameters.withCredentials;
    }
    /**
     * Select the correct content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param contentTypes - the array of content types that are available for selection
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderContentType(contentTypes) {
        if (contentTypes.length == 0) {
            return undefined;
        }
        let type = contentTypes.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return contentTypes[0];
        }
        return type;
    }
    /**
     * Select the correct accept content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct accept content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param accepts - the array of content types that are available for selection.
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderAccept(accepts) {
        if (accepts.length == 0) {
            return undefined;
        }
        let type = accepts.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return accepts[0];
        }
        return type;
    }
    /**
     * Check if the given MIME is a JSON MIME.
     * JSON MIME examples:
     *   application/json
     *   application/json; charset=UTF8
     *   APPLICATION/JSON
     *   application/vnd.company+json
     * @param mime - MIME (Multipurpose Internet Mail Extensions)
     * @return True if the given MIME is JSON, false otherwise.
     */
    isJsonMime(mime) {
        const jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
        return mime != null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
    }
}

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$1(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class BookingMigrationService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    dataBookingsPost($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling dataBookingsPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/data/v0-nsfw/bookings`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function BookingMigrationService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || BookingMigrationService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: BookingMigrationService, factory: BookingMigrationService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(BookingMigrationService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
* CustomHttpUrlEncodingCodec
* Fix plus sign (+) not encoding, so sent as blank space
* See: https://github.com/angular/angular/issues/11058#issuecomment-247367318
*/
class CustomHttpUrlEncodingCodec extends HttpUrlEncodingCodec {
    encodeKey(k) {
        k = super.encodeKey(k);
        return k.replace(/\+/gi, '%2B');
    }
    encodeValue(v) {
        v = super.encodeValue(v);
        return v.replace(/\+/gi, '%2B');
    }
}

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class ImportService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    dataImportBatchByIdGet($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling dataImportBatchByIdGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/data/v0-nsfw/import/batch/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    dataImportReservationsUploadPost($params, observe = 'body', reportProgress = false) {
        const formFile = $params.formFile;
        if (formFile === null || formFile === undefined) {
            throw new Error('Required parameter formFile was null or undefined when calling dataImportReservationsUploadPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'multipart/form-data'
        ];
        const canConsumeForm = this.canConsumeForm(consumes);
        let formParams;
        let useForm = false;
        let convertFormParamsToString = false;
        // use FormData to transmit files using content-type "multipart/form-data"
        // see https://stackoverflow.com/questions/4007969/application-x-www-form-urlencoded-or-multipart-form-data
        useForm = canConsumeForm;
        if (useForm) {
            formParams = new FormData();
        }
        else {
            formParams = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        }
        if (formFile !== undefined) {
            formParams = append(formParams, 'formFile', formFile);
        }
        return this.httpClient.post(`${this.basePath}/data/v0-nsfw/import/reservations-upload`, convertFormParamsToString ? formParams.toString() : formParams, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    dataImportTriggerBatchPost($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling dataImportTriggerBatchPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/data/v0-nsfw/import/trigger-batch`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function ImportService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || ImportService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: ImportService, factory: ImportService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ImportService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

const APIS = [BookingMigrationService, ImportService];

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MonetaryValueModel;
(function (MonetaryValueModel) {
    MonetaryValueModel.$metaData = {
        amount: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        currency: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(MonetaryValueModel || (MonetaryValueModel = {}));

var BookReservationServiceMigrationModel;
(function (BookReservationServiceMigrationModel) {
    BookReservationServiceMigrationModel.$metaData = {
        serviceId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        count: Object.freeze({
            type: 'number',
            isPrimitiveType: true,
        }),
        amount: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        dates: Object.freeze({
            type: 'Array<ModelDate>',
            isListContainer: true,
        }),
    };
})(BookReservationServiceMigrationModel || (BookReservationServiceMigrationModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var PersonAddressModel;
(function (PersonAddressModel) {
    PersonAddressModel.$metaData = {
        addressLine1: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        addressLine2: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        postalCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        city: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        regionCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        countryCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(PersonAddressModel || (PersonAddressModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var PersonCompanyMigrationModel;
(function (PersonCompanyMigrationModel) {
    PersonCompanyMigrationModel.$metaData = {
        name: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        taxId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(PersonCompanyMigrationModel || (PersonCompanyMigrationModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var BookerMigrationModel;
(function (BookerMigrationModel) {
    BookerMigrationModel.TitleEnumValues = Object.freeze(['Mr', 'Ms', 'Dr', 'Prof', 'Mrs', 'Other']);
    BookerMigrationModel.GenderEnumValues = Object.freeze(['Female', 'Male', 'Other', 'Unknown']);
    BookerMigrationModel.IdentificationTypeEnumValues = Object.freeze(['SocialInsuranceNumber', 'PassportNumber', 'IdNumber', 'DriverLicenseNumber', 'VisaNumber', 'ForeignerIdentityNumber', 'TaxIdentificationNumber', 'Other']);
})(BookerMigrationModel || (BookerMigrationModel = {}));
(function (BookerMigrationModel) {
    BookerMigrationModel.$metaData = {
        title: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: BookerMigrationModel.TitleEnumValues,
            isPrimitiveType: true,
        }),
        gender: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: BookerMigrationModel.GenderEnumValues,
            isPrimitiveType: true,
        }),
        firstName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        middleInitial: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        lastName: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        email: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        phone: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        address: Object.freeze({
            type: 'PersonAddressModel',
            metaData: PersonAddressModel.$metaData
        }),
        nationalityCountryCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationNumber: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationIssueDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationExpiryDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationType: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: BookerMigrationModel.IdentificationTypeEnumValues,
            isPrimitiveType: true,
        }),
        company: Object.freeze({
            type: 'PersonCompanyMigrationModel',
            metaData: PersonCompanyMigrationModel.$metaData
        }),
        preferredLanguage: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthPlace: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(BookerMigrationModel || (BookerMigrationModel = {}));

var BookingCreatedMigrationModel;
(function (BookingCreatedMigrationModel) {
    BookingCreatedMigrationModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        reservationIds: Object.freeze({
            isRequired: true,
            type: 'Array<ReservationCreatedMigrationModel>',
            isListContainer: true,
        }),
    };
})(BookingCreatedMigrationModel || (BookingCreatedMigrationModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CommissionModel;
(function (CommissionModel) {
    CommissionModel.$metaData = {
        commissionAmount: Object.freeze({
            isRequired: true,
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        beforeCommissionAmount: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
    };
})(CommissionModel || (CommissionModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CreatePaymentAccountMigrationModel;
(function (CreatePaymentAccountMigrationModel) {
    CreatePaymentAccountMigrationModel.$metaData = {
        accountNumber: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        accountHolder: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        expiryMonth: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        expiryYear: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        paymentMethod: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        payerEmail: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        payerReference: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        isVirtual: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        inactiveReason: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CreatePaymentAccountMigrationModel || (CreatePaymentAccountMigrationModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CreateBookingMigrationModel;
(function (CreateBookingMigrationModel) {
    CreateBookingMigrationModel.$metaData = {
        paymentAccount: Object.freeze({
            type: 'CreatePaymentAccountMigrationModel',
            metaData: CreatePaymentAccountMigrationModel.$metaData
        }),
        booker: Object.freeze({
            isRequired: true,
            type: 'BookerMigrationModel',
            metaData: BookerMigrationModel.$metaData
        }),
        comment: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        bookerComment: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        reservations: Object.freeze({
            isRequired: true,
            type: 'Array<CreateReservationMigrationModel>',
            isListContainer: true,
        }),
        transactionReference: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CreateBookingMigrationModel || (CreateBookingMigrationModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ExternalReferencesMigrationModel;
(function (ExternalReferencesMigrationModel) {
    ExternalReferencesMigrationModel.$metaData = {
        globalDistributionSystemId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        onlineTravelAgencyId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        onlineBookingToolId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        channelManagerId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        legacyId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ExternalReferencesMigrationModel || (ExternalReferencesMigrationModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var GuestMigrationModel;
(function (GuestMigrationModel) {
    GuestMigrationModel.TitleEnumValues = Object.freeze(['Mr', 'Ms', 'Dr', 'Prof', 'Mrs', 'Other']);
    GuestMigrationModel.GenderEnumValues = Object.freeze(['Female', 'Male', 'Other', 'Unknown']);
    GuestMigrationModel.IdentificationTypeEnumValues = Object.freeze(['SocialInsuranceNumber', 'PassportNumber', 'IdNumber', 'DriverLicenseNumber', 'VisaNumber', 'ForeignerIdentityNumber', 'TaxIdentificationNumber', 'Other']);
    GuestMigrationModel.RelationshipToPrimaryGuestEnumValues = Object.freeze(['Grandparent', 'Grandchild', 'GreatGrandparent', 'GreatGrandchild', 'Parent', 'Child', 'Sibling', 'ParentInLaw', 'ChildInLaw', 'SiblingInLaw', 'Spouse', 'UncleOrAunt', 'NephewOrNiece', 'Guardian', 'Other']);
})(GuestMigrationModel || (GuestMigrationModel = {}));
(function (GuestMigrationModel) {
    GuestMigrationModel.$metaData = {
        title: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: GuestMigrationModel.TitleEnumValues,
            isPrimitiveType: true,
        }),
        gender: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: GuestMigrationModel.GenderEnumValues,
            isPrimitiveType: true,
        }),
        firstName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        middleInitial: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        lastName: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        secondLastName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        email: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        phone: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        address: Object.freeze({
            type: 'PersonAddressModel',
            metaData: PersonAddressModel.$metaData
        }),
        nationalityCountryCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationNumber: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationAdditionalNumber: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationIssueDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationExpiryDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationIssuePlace: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationType: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: GuestMigrationModel.IdentificationTypeEnumValues,
            isPrimitiveType: true,
        }),
        personalTaxId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        company: Object.freeze({
            type: 'PersonCompanyMigrationModel',
            metaData: PersonCompanyMigrationModel.$metaData
        }),
        preferredLanguage: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthPlace: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthFirstName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthLastName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        motherFirstName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        motherLastName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        borderCrossingPlace: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        borderCrossingDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        relationshipToPrimaryGuest: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: GuestMigrationModel.RelationshipToPrimaryGuestEnumValues,
            isPrimitiveType: true,
        }),
    };
})(GuestMigrationModel || (GuestMigrationModel = {}));

var CreateReservationMigrationModel;
(function (CreateReservationMigrationModel) {
    CreateReservationMigrationModel.ChannelCodeEnumValues = Object.freeze(['Direct', 'BookingCom', 'Ibe', 'ChannelManager', 'Expedia', 'Homelike', 'Hrs', 'AltoVita', 'DesVu']);
    CreateReservationMigrationModel.GuaranteeTypeEnumValues = Object.freeze(['PM6Hold', 'CreditCard', 'Prepayment', 'Company']);
    CreateReservationMigrationModel.TravelPurposeEnumValues = Object.freeze(['Business', 'Leisure']);
})(CreateReservationMigrationModel || (CreateReservationMigrationModel = {}));
(function (CreateReservationMigrationModel) {
    CreateReservationMigrationModel.$metaData = {
        arrival: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        departure: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        adults: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        childrenAges: Object.freeze({
            type: 'Array<number>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
        comment: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        guestComment: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        externalCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        channelCode: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateReservationMigrationModel.ChannelCodeEnumValues,
            isPrimitiveType: true,
        }),
        source: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        primaryGuest: Object.freeze({
            type: 'GuestMigrationModel',
            metaData: GuestMigrationModel.$metaData
        }),
        additionalGuests: Object.freeze({
            type: 'Array<GuestMigrationModel>',
            isListContainer: true,
        }),
        guaranteeType: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateReservationMigrationModel.GuaranteeTypeEnumValues,
            isPrimitiveType: true,
        }),
        travelPurpose: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateReservationMigrationModel.TravelPurposeEnumValues,
            isPrimitiveType: true,
        }),
        timeSlices: Object.freeze({
            isRequired: true,
            type: 'Array<CreateReservationTimeSliceMigrationModel>',
            isListContainer: true,
        }),
        services: Object.freeze({
            type: 'Array<BookReservationServiceMigrationModel>',
            isListContainer: true,
        }),
        companyId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        corporateCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        prePaymentAmount: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        commission: Object.freeze({
            type: 'CommissionModel',
            metaData: CommissionModel.$metaData
        }),
        promoCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        externalReferences: Object.freeze({
            type: 'ExternalReferencesMigrationModel',
            metaData: ExternalReferencesMigrationModel.$metaData
        }),
    };
})(CreateReservationMigrationModel || (CreateReservationMigrationModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CreateReservationTimeSliceMigrationModel;
(function (CreateReservationTimeSliceMigrationModel) {
    CreateReservationTimeSliceMigrationModel.$metaData = {
        ratePlanId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        totalAmount: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
    };
})(CreateReservationTimeSliceMigrationModel || (CreateReservationTimeSliceMigrationModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MessageItemCollection;
(function (MessageItemCollection) {
    MessageItemCollection.$metaData = {
        messages: Object.freeze({
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
    };
})(MessageItemCollection || (MessageItemCollection = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MigrationBatchCreatedModel;
(function (MigrationBatchCreatedModel) {
    MigrationBatchCreatedModel.$metaData = {
        batchId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(MigrationBatchCreatedModel || (MigrationBatchCreatedModel = {}));

var MigrationBatchModel;
(function (MigrationBatchModel) {
    MigrationBatchModel.TypeEnumValues = Object.freeze(['ReservationImport']);
    MigrationBatchModel.StatusEnumValues = Object.freeze(['Uploaded', 'Running', 'Successful', 'Failure']);
})(MigrationBatchModel || (MigrationBatchModel = {}));
(function (MigrationBatchModel) {
    MigrationBatchModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: MigrationBatchModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
        status: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: MigrationBatchModel.StatusEnumValues,
            isPrimitiveType: true,
        }),
        created: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        updated: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        items: Object.freeze({
            isRequired: true,
            type: 'Array<MigrationItemModel>',
            isListContainer: true,
        }),
    };
})(MigrationBatchModel || (MigrationBatchModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MigrationItemModel;
(function (MigrationItemModel) {
    MigrationItemModel.StatusEnumValues = Object.freeze(['Uploaded', 'Successful', 'SuccessfulWithWarning', 'Failure']);
})(MigrationItemModel || (MigrationItemModel = {}));
(function (MigrationItemModel) {
    MigrationItemModel.$metaData = {
        status: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: MigrationItemModel.StatusEnumValues,
            isPrimitiveType: true,
        }),
        message: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        created: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        updated: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        data: Object.freeze({
            isRequired: true,
            type: 'any',
            isPrimitiveType: true,
        }),
    };
})(MigrationItemModel || (MigrationItemModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ModelDate;
(function (ModelDate) {
    ModelDate.$metaData = {
        serviceDate: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        count: Object.freeze({
            type: 'number',
            isPrimitiveType: true,
        }),
        amount: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
    };
})(ModelDate || (ModelDate = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationCreatedMigrationModel;
(function (ReservationCreatedMigrationModel) {
    ReservationCreatedMigrationModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ReservationCreatedMigrationModel || (ReservationCreatedMigrationModel = {}));

/**
 * apaleo Data API - not safe for work
 * Continuously evolving version - use at your own risk! Import transactional data from other PMS.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var TriggerBatchModel;
(function (TriggerBatchModel) {
    TriggerBatchModel.$metaData = {
        batchId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(TriggerBatchModel || (TriggerBatchModel = {}));

class ApiModule {
    static forRoot(configurationFactory) {
        return {
            ngModule: ApiModule,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    }
    constructor(parentModule, http) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
        }
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
    static { this.ɵfac = function ApiModule_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || ApiModule)(i0.ɵɵinject(ApiModule, 12), i0.ɵɵinject(i1.HttpClient, 8)); }; }
    static { this.ɵmod = /*@__PURE__*/ i0.ɵɵdefineNgModule({ type: ApiModule }); }
    static { this.ɵinj = /*@__PURE__*/ i0.ɵɵdefineInjector({ providers: [
            BookingMigrationService,
            ImportService
        ] }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ApiModule, [{
        type: NgModule,
        args: [{
                imports: [],
                declarations: [],
                exports: [],
                providers: [
                    BookingMigrationService,
                    ImportService
                ]
            }]
    }], () => [{ type: ApiModule, decorators: [{
                type: Optional
            }, {
                type: SkipSelf
            }] }, { type: i1.HttpClient, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * Generated bundle index. Do not edit.
 */

export { APIS, ApiModule, BASE_PATH, BookReservationServiceMigrationModel, BookerMigrationModel, BookingCreatedMigrationModel, BookingMigrationService, COLLECTION_FORMATS, CommissionModel, Configuration, CreateBookingMigrationModel, CreatePaymentAccountMigrationModel, CreateReservationMigrationModel, CreateReservationTimeSliceMigrationModel, ExternalReferencesMigrationModel, GuestMigrationModel, ImportService, MessageItemCollection, MigrationBatchCreatedModel, MigrationBatchModel, MigrationItemModel, ModelDate, MonetaryValueModel, PersonAddressModel, PersonCompanyMigrationModel, ReservationCreatedMigrationModel, TriggerBatchModel };
//# sourceMappingURL=apaleo-angular-api-proxy-data.mjs.map
